#' @keywords internal
"_PACKAGE"

#' @importFrom tibble tibble as_tibble
#' @importFrom rlang %||% abort arg_match check_installed inform .data
#' @importFrom dplyr bind_rows
#' @importFrom cli cli_inform cli_progress_bar cli_progress_update cli_progress_done
#' @importFrom glue glue
#' @importFrom httr2 request
#' @importFrom httr2 req_url_path_append
#' @importFrom httr2 req_user_agent
#' @importFrom httr2 req_retry
#' @importFrom httr2 req_throttle
#' @importFrom httr2 req_error
#' @importFrom httr2 req_auth_bearer_token
#' @importFrom httr2 req_url_query
#' @importFrom httr2 req_method
#' @importFrom httr2 req_body_json
#' @importFrom httr2 req_perform
#' @importFrom httr2 resp_body_json
#' @importFrom httr2 resp_status
NULL
