% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/netvis.R
\name{get_subgraph}
\alias{get_subgraph}
\title{Get subgraph for a set of nodes}
\usage{
get_subgraph(node_ids, limit = 200L)
}
\arguments{
\item{node_ids}{Character vector of node IDs (max 50).}

\item{limit}{Maximum edges (default 200).}
}
\value{
A named list with \verb{$nodes} (\code{\link[tibble:tibble]{tibble::tibble()}}), \verb{$edges}
(\code{\link[tibble:tibble]{tibble::tibble()}}), and \verb{$has_more}.
}
\description{
Get subgraph for a set of nodes
}
\examples{
\dontrun{
get_subgraph(c("H:UNITCM_H001", "C:UNITCM_I00001"))
}
}
