% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{clear_api_key}
\alias{clear_api_key}
\title{Clear the UniTCM API Key}
\usage{
clear_api_key(keyring = FALSE)
}
\arguments{
\item{keyring}{Logical. If \code{TRUE}, also remove from system keyring.}
}
\value{
Invisible \code{NULL}.
}
\description{
Removes the API key from session memory and optionally from the system
keyring.
}
\examples{
\dontrun{
clear_api_key()
}
}
