% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{get_base_url}
\alias{get_base_url}
\title{Get the UniTCM API base URL}
\usage{
get_base_url()
}
\value{
A character string.
}
\description{
Checks in order: (1) session value set via \code{\link[=set_base_url]{set_base_url()}},
(2) option \code{unitcm.base_url}, (3) environment variable \code{UNITCM_BASE_URL},
(4) hardcoded default.
}
\examples{
\dontrun{
get_base_url()
}
}
