% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ontology.R
\name{get_ontology_entity}
\alias{get_ontology_entity}
\title{Get a TCM ontology entity}
\usage{
get_ontology_entity(tcm_id)
}
\arguments{
\item{tcm_id}{The TCM ontology ID (e.g. \code{"TCM_0001"}).}
}
\value{
A named list with sub-elements: \code{ancestors}, \code{children},
\code{external_mappings}, \code{relations}.
}
\description{
Retrieve full detail for one entity including ancestors, children,
external mappings, and relations.
}
\examples{
\dontrun{
get_ontology_entity("TCM_0001")
}
}
