% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/disease-formula.R
\name{fetch_disease_tree}
\alias{fetch_disease_tree}
\title{Get the ICD-11 disease classification tree}
\usage{
fetch_disease_tree()
}
\value{
A recursive nested list with structure
\code{list(label, count, children = list(...))}.
}
\description{
Returns the full 4-level ICD-11 disease classification tree used by the
Disease-Formula Atlas.
}
\examples{
\dontrun{
tree <- fetch_disease_tree()
names(tree[[1]])
}
}
