% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/network.R
\name{as_igraph}
\alias{as_igraph}
\title{Convert a NetVis graph response to igraph}
\usage{
as_igraph(graph_response)
}
\arguments{
\item{graph_response}{A list with \verb{$nodes} and \verb{$edges} tibbles, as
returned by \code{\link[=get_neighbors]{get_neighbors()}}, \code{\link[=get_subgraph]{get_subgraph()}}, or \code{\link[=find_path]{find_path()}}.}
}
\value{
An \code{igraph} graph object.
}
\description{
Convert a NetVis graph response to igraph
}
\examples{
\dontrun{
resp <- get_neighbors("H:UNITCM_H001")
g <- as_igraph(resp)
}
}
