% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{set_unitcm_token}
\alias{set_unitcm_token}
\title{Set a UniTCM API token}
\usage{
set_unitcm_token(token, keyring = FALSE)
}
\arguments{
\item{token}{A character string. The bearer token.}

\item{keyring}{Logical. If \code{TRUE}, also store in system keyring.}
}
\value{
Invisible \code{NULL}.
}
\description{
Stores the token in session memory. Optionally also stores it in the
system keyring (requires the \pkg{keyring} package).
}
\examples{
\dontrun{
set_unitcm_token("my-secret-token")
}
}
