% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{unitcm_cache_clear}
\alias{unitcm_cache_clear}
\title{Clear unitcm cache}
\usage{
unitcm_cache_clear()
}
\value{
Invisible \code{NULL}.
}
\description{
Clears any memoized API results. Currently a no-op placeholder for
future caching support.
}
