% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/disease-formula.R
\name{get_formula_doses}
\alias{get_formula_doses}
\title{Get herb doses for a formula}
\usage{
get_formula_doses(order_id)
}
\arguments{
\item{order_id}{The formula order ID.}
}
\value{
A \code{\link[tibble:tibble]{tibble::tibble()}} with columns: \code{id}, \code{herb_name},
\code{original_dose}, \code{composition_ratio}, \code{modern_dose_g},
\code{clinical_ref_dose_g}, \code{dynasty}, \code{notes}, \code{herb_ids}.
}
\description{
Retrieve the composition and dosage information for a specific formula.
}
\examples{
\dontrun{
get_formula_doses(1)
}
}
