% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{flatten_response}
\alias{flatten_response}
\title{Flatten a nested API response to a tibble}
\usage{
flatten_response(x)
}
\arguments{
\item{x}{A named list from an API response.}
}
\value{
A single-row \code{\link[tibble:tibble]{tibble::tibble()}}.
}
\description{
Recursively flattens a nested list into a single-row tibble. Nested lists
that cannot be further flattened are kept as list-columns.
}
\examples{
\dontrun{
herb <- get_herb("UNITCM_H001")
flatten_response(herb)
}
}
